@@ -80,20 +80,29 @@ use warnings FATAL => 'all';
 
 use App::Dochazka::REST;
 
+EOH
+
+# DOCHAZKA_DOCGEN_POD_PREAMBLE
+#     preamble of Resources.pm, which is generated by docgen.sh
+set( 'DOCHAZKA_DOCGEN_POD_PREAMBLE', <<'EOH' );
 
 =head1 NAME
 
 App::Dochazka::REST::Docs::Resources - Documentation of App::Dochazka::REST resources
 
 
+=head1 DESCRIPTION
+
+This is a POD-only module containing documentation on all the REST resources 
+defined under C<config/dispatch>. This module is auto-generated.
+
 EOH
 
 # DOCHAZKA_DOCGEN_EPITAPH
 #     the last bit of Resources.pm, which is generated by docgen.sh
 set( 'DOCHAZKA_DOCGEN_EPITAPH', <<'EOH' );
-=cut
 
-1;
+=cut
 EOH
 
 # -----------------------------------
